@@ -73,6 +73,12 @@ pub enum NullableResult<T, E> {
     None,
 }
 
+impl<T, E> Default for NullableResult<T, E> {
+    fn default() -> Self {
+        NullableResult::None
+    }
+}
+
 impl<T, E: Debug> NullableResult<T, E> {
     /// Panics if it's not `Ok`, otherwise returns the contained value.
     #[inline]
@@ -185,6 +191,16 @@ impl<T, E> From<NullableResult<T, E>> for Result<Option<T>, E> {
     }
 }
 
+impl<T, E> From<Result<T, E>> for NullableResult<T, E> {
+    #[inline]
+    fn from(res: Result<T, E>) -> Self {
+        match res {
+            Ok(item) => NullableResult::Ok(item),
+            Err(err) => NullableResult::Err(err),
+        }
+    }
+}
+
 impl<T, E> From<Option<Result<T, E>>> for NullableResult<T, E> {
     #[inline]
     fn from(opt: Option<Result<T, E>>) -> Self {
@@ -207,6 +223,16 @@ impl<T, E> From<NullableResult<T, E>> for Option<Result<T, E>> {
     }
 }
 
+impl<T, E> From<Option<T>> for NullableResult<T, E> {
+    #[inline]
+    fn from(opt: Option<T>) -> Self {
+        match opt {
+            Some(item) => NullableResult::Ok(item),
+            None => NullableResult::None,
+        }
+    }
+}
+
 #[macro_export]
 macro_rules! extract {
     ($nr:expr) => {{
@@ -214,10 +240,10 @@ macro_rules! extract {
         match nr {
             nullable_result::NullableResult::Ok(item) => item,
             nullable_result::NullableResult::Err(err) => {
-                return NullableResult::Err(err)
+                return NullableResult::Err(err);
             }
             nullable_result::NullableResult::None => {
-                return NullableResult::None
+                return NullableResult::None;
             }
         }
     }};
